'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsCore = require('@lorisleiva/js-core');
var sha512 = require('@noble/hashes/sha512');

const createDerivedSigner = async (context, originalSigner, message) => {
  const messageBytes = typeof message === 'string' ? jsCore.utf8.serialize(message) : message;
  const signature = await originalSigner.signMessage(messageBytes);
  const seeds = sha512.sha512(signature).slice(0, 32);
  const keypair = context.eddsa.createKeypairFromSeed(seeds);
  return {
    ...jsCore.createSignerFromKeypair(context, keypair),
    originalSigner
  };
};
const isDerivedKeypair = signer => signer.originalSigner !== undefined && jsCore.isKeypairSigner(signer);

exports.createDerivedSigner = createDerivedSigner;
exports.isDerivedKeypair = isDerivedKeypair;
//# sourceMappingURL=DerivedSigner.cjs.map
